.. _model_gallery_ref:

:mod:`biolearn.model_gallery`: ModelGallery
============================================

.. automodule:: biolearn.model_gallery
   :no-members:
   :no-inherited-members:

**Classes**:

.. currentmodule:: biolearn.model_gallery

.. autosummary::
   :toctree: generated/
   :template: class.rst

   ModelGallery
